"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryComplexityExtensionPlugin = void 0;
const graphql_query_complexity_1 = require("graphql-query-complexity");
const queryComplexityExtensionPlugin = (schema, maxComlexity = Infinity, throwOnMaximum = true) => {
    return {
        requestDidStart: async () => {
            let complexity;
            return {
                didResolveOperation: async (reqContext) => {
                    const { request, document } = reqContext;
                    complexity = graphql_query_complexity_1.getComplexity({
                        schema,
                        operationName: request.operationName,
                        query: document,
                        variables: request.variables,
                        estimators: [
                            graphql_query_complexity_1.fieldExtensionsEstimator(),
                            graphql_query_complexity_1.simpleEstimator({ defaultComplexity: 1 }),
                        ],
                    });
                    if (maxComlexity !== Infinity &&
                        complexity > maxComlexity &&
                        throwOnMaximum) {
                        process.env.SERVERLESS_OUTPUT_ERROR_STACK === 'true';
                        throw new Error(`Current query complexity is ${complexity} and max allowed complexity is ${maxComlexity}`);
                    }
                },
                willSendResponse: async (reqContext) => {
                    reqContext.response.extensions = {
                        ...reqContext.response.extensions,
                        CURRENT_COMPLEXITY: complexity,
                    };
                },
            };
        },
    };
};
exports.queryComplexityExtensionPlugin = queryComplexityExtensionPlugin;
